@@ -23,6 +23,7 @@ use OCA\News\Config\FetcherConfig;
 use OCA\News\Hooks\UserDeleteHook;
 use OCA\News\Search\FeedSearchProvider;
 use OCA\News\Search\FolderSearchProvider;
+use OCA\News\Search\ItemSearchProvider;
 
 use OCP\AppFramework\Bootstrap\IBootContext;
 use OCP\AppFramework\Bootstrap\IBootstrap;
@@ -82,6 +83,8 @@ class Application extends App implements IBootstrap
 
         $context->registerSearchProvider(FolderSearchProvider::class);
         $context->registerSearchProvider(FeedSearchProvider::class);
+        $context->registerSearchProvider(ItemSearchProvider::class);
+
 
         $context->registerEventListener(BeforeUserDeletedEvent::class, UserDeleteHook::class);
 
