@@ -221,6 +221,25 @@ class ItemApiController extends ApiController
     }
 
 
+    /**
+     * @param int  $itemId
+     * @param bool $isStarred
+     *
+     * @return array|JSONResponse
+     * @throws ServiceConflictException
+     */
+    private function setStarredByItemId(int $itemId, bool $isStarred)
+    {
+        try {
+            $this->itemService->star($this->getUserId(), $itemId, $isStarred);
+        } catch (ServiceNotFoundException $ex) {
+            return $this->error($ex, Http::STATUS_NOT_FOUND);
+        }
+
+        return [];
+    }
+
+
     /**
      * @NoAdminRequired
      * @NoCSRFRequired
@@ -255,6 +274,38 @@ class ItemApiController extends ApiController
     }
 
 
+    /**
+     * @NoAdminRequired
+     * @NoCSRFRequired
+     * @CORS
+     *
+     * @param int $itemId
+     *
+     * @return array|JSONResponse
+     * @throws ServiceConflictException
+     */
+    public function starByItemId(int $itemId)
+    {
+        return $this->setStarredByItemId($itemId, true);
+    }
+
+
+    /**
+     * @NoAdminRequired
+     * @NoCSRFRequired
+     * @CORS
+     *
+     * @param int $itemId
+     *
+     * @return array|JSONResponse
+     * @throws ServiceConflictException
+     */
+    public function unstarByItemId(int $itemId)
+    {
+        return $this->setStarredByItemId($itemId, false);
+    }
+
+
     /**
      * @NoAdminRequired
      *
@@ -272,14 +323,14 @@ class ItemApiController extends ApiController
     }
 
     /**
-     * @param array $items
+     * @param array $itemIds
      * @param bool  $isRead
      *
      * @throws ServiceConflictException
      */
-    private function setMultipleRead(array $items, bool $isRead): void
+    private function setMultipleRead(array $itemIds, bool $isRead): void
     {
-        foreach ($items as $id) {
+        foreach ($itemIds as $id) {
             try {
                 $this->itemService->read($this->getUserId(), $id, $isRead);
             } catch (ServiceNotFoundException $ex) {
@@ -308,6 +359,23 @@ class ItemApiController extends ApiController
     }
 
 
+    /**
+     * @NoAdminRequired
+     * @NoCSRFRequired
+     * @CORS
+     *
+     * @param int[] $itemIds item ids
+     *
+     * @return void
+     *
+     * @throws ServiceConflictException
+     */
+    public function readMultipleByIds(array $itemIds): void
+    {
+        $this->setMultipleRead($itemIds, true);
+    }
+
+
     /**
      * @NoAdminRequired
      *
@@ -327,6 +395,23 @@ class ItemApiController extends ApiController
     }
 
 
+    /**
+     * @NoAdminRequired
+     * @NoCSRFRequired
+     * @CORS
+     *
+     * @param int[] $itemIds item ids
+     *
+     * @return void
+     *
+     * @throws ServiceConflictException
+     */
+    public function unreadMultipleByIds(array $itemIds): void
+    {
+        $this->setMultipleRead($itemIds, false);
+    }
+
+
     /**
      * @param array $items
      * @param bool  $isStarred
@@ -350,6 +435,28 @@ class ItemApiController extends ApiController
     }
 
 
+    /**
+     * @param array $itemIds
+     * @param bool  $isStarred
+     *
+     * @return void
+     */
+    private function setMultipleStarredByItemIds(array $itemIds, bool $isStarred): void
+    {
+        foreach ($itemIds as $itemId) {
+            try {
+                $this->itemService->star(
+                    $this->getUserId(),
+                    $itemId,
+                    $isStarred
+                );
+            } catch (ServiceNotFoundException | ServiceConflictException $ex) {
+                continue;
+            }
+        }
+    }
+
+
     /**
      * @NoAdminRequired
      *
@@ -357,7 +464,7 @@ class ItemApiController extends ApiController
      *
      * @CORS
      *
-     * @param int[] $items item ids
+     * @param int[] $items items
      *
      * @return void
      */
@@ -374,7 +481,7 @@ class ItemApiController extends ApiController
      *
      * @CORS
      *
-     * @param array $items item ids
+     * @param array $items items
      *
      * @return void
      */
@@ -382,4 +489,34 @@ class ItemApiController extends ApiController
     {
         $this->setMultipleStarred($items, false);
     }
+
+
+    /**
+     * @NoAdminRequired
+     * @NoCSRFRequired
+     * @CORS
+     *
+     * @param int[] $items item ids
+     *
+     * @return void
+     */
+    public function starMultipleByItemIds(array $itemIds): void
+    {
+        $this->setMultipleStarredByItemIds($itemIds, true);
+    }
+
+
+    /**
+     * @NoAdminRequired
+     * @NoCSRFRequired
+     * @CORS
+     *
+     * @param array $items item ids
+     *
+     * @return void
+     */
+    public function unstarMultipleByItemIds(array $itemIds): void
+    {
+        $this->setMultipleStarredByItemIds($itemIds, false);
+    }
 }
