@@ -31,6 +31,7 @@ use OCA\News\Db\Item;
 use OCA\News\Db\Feed;
 use OCA\News\Utility\Time;
 use OCA\News\Scraper\Scraper;
+use OCA\News\Config\FetcherConfig;
 use Psr\Log\LoggerInterface;
 use SimpleXMLElement;
 
@@ -113,15 +114,21 @@ class FeedFetcher implements IFeedFetcher
         string $url,
         bool $fullTextEnabled,
         ?string $user,
-        ?string $password
+        ?string $password,
+        ?string $httpLastModified
     ): array {
         $url2 = new Net_URL2($url);
         if (!is_null($user) && trim($user) !== '') {
             $url2->setUserinfo(rawurlencode($user), rawurlencode($password));
         }
+        if (!is_null($httpLastModified) && trim($httpLastModified) !== '') {
+            $lastModified = new DateTime($httpLastModified);
+        } else {
+            $lastModified = null;
+        }
         $url = $url2->getNormalizedURL();
         $this->reader->resetFilters();
-        $resource = $this->reader->read($url);
+        $resource = $this->reader->read($url, null, $lastModified);
 
         $location     = $resource->getUrl();
         $parsedFeed   = $resource->getFeed();
@@ -364,7 +371,7 @@ class FeedFetcher implements IFeedFetcher
             $favicon = trim($feed_logo);
         }
         
-        ini_set('user_agent', 'NextCloud-News/1.0');
+        ini_set('user_agent', FetcherConfig::DEFAULT_USER_AGENT);
 
         $base_url = new Net_URL2($url);
         $base_url->setPath("");
@@ -400,7 +407,7 @@ class FeedFetcher implements IFeedFetcher
                 [
                     'sink' => $favicon_path,
                     'headers' => [
-                        'User-Agent'        => 'NextCloud-News/1.0',
+                        'User-Agent'        => FetcherConfig::DEFAULT_USER_AGENT,
                         'Accept'            => 'image/*',
                         'If-Modified-Since' => date(DateTime::RFC7231, $last_modified)
                     ]
